@@ -36,9 +36,9 @@ const FRAGMENT_ENCODE_SET: &AsciiSet = &percent_encoding::CONTROLS
 const ID_ENCODE_SET: &AsciiSet = &FRAGMENT_ENCODE_SET.add(b'|');
 
 use crate::{Api,
-     DeactiveUserResponse,
+     ActivateUserResponse,
+     DeactivateUserResponse,
      UpdatePasswordResponse,
-     UpdateUserInfoResponse,
      QueryUserByIdResponse,
      QueryUsersResponse
      };
@@ -384,16 +384,14 @@ impl<S, C> Api<C> for Client<S, C> where
         }
     }
 
-    async fn deactive_user(
+    async fn activate_user(
         &self,
-        param_id: uuid::Uuid,
-        context: &C) -> Result<DeactiveUserResponse, ApiError>
+        context: &C) -> Result<ActivateUserResponse, ApiError>
     {
         let mut client_service = self.client_service.clone();
         let mut uri = format!(
-            "{}/mutation-api/user/deactive/{id}",
+            "{}/mutation-api/users/activation",
             self.base_path
-            ,id=utf8_percent_encode(&param_id.to_string(), ID_ENCODE_SET)
         );
 
         // Query parameters
@@ -412,7 +410,7 @@ impl<S, C> Api<C> for Client<S, C> where
         };
 
         let mut request = match Request::builder()
-            .method("PUT")
+            .method("POST")
             .uri(uri)
             .body(Body::empty()) {
                 Ok(req) => req,
@@ -454,14 +452,112 @@ impl<S, C> Api<C> for Client<S, C> where
                 let body = str::from_utf8(&body)
                     .map_err(|e| ApiError(format!("Response was not valid UTF8: {}", e)))?;
                 let body = serde_json::from_str::<models::User>(body)?;
-                Ok(DeactiveUserResponse::SuccessfulOperation
+                Ok(ActivateUserResponse::SuccessfulOperation
                     (body)
                 )
             }
             405 => {
                 let body = response.into_body();
                 Ok(
-                    DeactiveUserResponse::InvalidInput
+                    ActivateUserResponse::InvalidInput
+                )
+            }
+            code => {
+                let headers = response.headers().clone();
+                let body = response.into_body()
+                       .take(100)
+                       .to_raw().await;
+                Err(ApiError(format!("Unexpected response code {}:\n{:?}\n\n{}",
+                    code,
+                    headers,
+                    match body {
+                        Ok(body) => match String::from_utf8(body) {
+                            Ok(body) => body,
+                            Err(e) => format!("<Body was not UTF8: {:?}>", e),
+                        },
+                        Err(e) => format!("<Failed to read body: {}>", e),
+                    }
+                )))
+            }
+        }
+    }
+
+    async fn deactivate_user(
+        &self,
+        context: &C) -> Result<DeactivateUserResponse, ApiError>
+    {
+        let mut client_service = self.client_service.clone();
+        let mut uri = format!(
+            "{}/mutation-api/users/deactivation",
+            self.base_path
+        );
+
+        // Query parameters
+        let query_string = {
+            let mut query_string = form_urlencoded::Serializer::new("".to_owned());
+            query_string.finish()
+        };
+        if !query_string.is_empty() {
+            uri += "?";
+            uri += &query_string;
+        }
+
+        let uri = match Uri::from_str(&uri) {
+            Ok(uri) => uri,
+            Err(err) => return Err(ApiError(format!("Unable to build URI: {}", err))),
+        };
+
+        let mut request = match Request::builder()
+            .method("POST")
+            .uri(uri)
+            .body(Body::empty()) {
+                Ok(req) => req,
+                Err(e) => return Err(ApiError(format!("Unable to create request: {}", e)))
+        };
+
+        let header = HeaderValue::from_str(Has::<XSpanIdString>::get(context).0.clone().to_string().as_str());
+        request.headers_mut().insert(HeaderName::from_static("x-span-id"), match header {
+            Ok(h) => h,
+            Err(e) => return Err(ApiError(format!("Unable to create X-Span ID header value: {}", e)))
+        });
+
+        if let Some(auth_data) = Has::<Option<AuthData>>::get(context).as_ref() {
+            // Currently only authentication with Basic and Bearer are supported
+            match auth_data {
+                &AuthData::Bearer(ref bearer_header) => {
+                    let auth = swagger::auth::Header(bearer_header.clone());
+                    let header = match HeaderValue::from_str(&format!("{}", auth)) {
+                        Ok(h) => h,
+                        Err(e) => return Err(ApiError(format!("Unable to create Authorization header: {}", e)))
+                    };
+                    request.headers_mut().insert(
+                        hyper::header::AUTHORIZATION,
+                        header);
+                },
+                _ => {}
+            }
+        }
+
+        let mut response = client_service.call((request, context.clone()))
+            .map_err(|e| ApiError(format!("No response received: {}", e))).await?;
+
+        match response.status().as_u16() {
+            200 => {
+                let body = response.into_body();
+                let body = body
+                        .to_raw()
+                        .map_err(|e| ApiError(format!("Failed to read response: {}", e))).await?;
+                let body = str::from_utf8(&body)
+                    .map_err(|e| ApiError(format!("Response was not valid UTF8: {}", e)))?;
+                let body = serde_json::from_str::<models::User>(body)?;
+                Ok(DeactivateUserResponse::SuccessfulOperation
+                    (body)
+                )
+            }
+            405 => {
+                let body = response.into_body();
+                Ok(
+                    DeactivateUserResponse::InvalidInput
                 )
             }
             code => {
@@ -486,15 +582,13 @@ impl<S, C> Api<C> for Client<S, C> where
 
     async fn update_password(
         &self,
-        param_id: uuid::Uuid,
         param_inline_object: models::InlineObject,
         context: &C) -> Result<UpdatePasswordResponse, ApiError>
     {
         let mut client_service = self.client_service.clone();
         let mut uri = format!(
-            "{}/mutation-api/user/update-password/{id}",
+            "{}/mutation-api/users/password",
             self.base_path
-            ,id=utf8_percent_encode(&param_id.to_string(), ID_ENCODE_SET)
         );
 
         // Query parameters
@@ -521,6 +615,7 @@ impl<S, C> Api<C> for Client<S, C> where
         };
 
         let body = serde_json::to_string(&param_inline_object).expect("impossible to fail to serialize");
+
                 *request.body_mut() = Body::from(body);
 
         let header = "application/json";
@@ -528,6 +623,7 @@ impl<S, C> Api<C> for Client<S, C> where
             Ok(h) => h,
             Err(e) => return Err(ApiError(format!("Unable to create header: {} - {}", header, e)))
         });
+
         let header = HeaderValue::from_str(Has::<XSpanIdString>::get(context).0.clone().to_string().as_str());
         request.headers_mut().insert(HeaderName::from_static("x-span-id"), match header {
             Ok(h) => h,
@@ -593,117 +689,6 @@ impl<S, C> Api<C> for Client<S, C> where
         }
     }
 
-    async fn update_user_info(
-        &self,
-        param_id: uuid::Uuid,
-        param_user: models::User,
-        context: &C) -> Result<UpdateUserInfoResponse, ApiError>
-    {
-        let mut client_service = self.client_service.clone();
-        let mut uri = format!(
-            "{}/mutation-api/user/update-info/{id}",
-            self.base_path
-            ,id=utf8_percent_encode(&param_id.to_string(), ID_ENCODE_SET)
-        );
-
-        // Query parameters
-        let query_string = {
-            let mut query_string = form_urlencoded::Serializer::new("".to_owned());
-            query_string.finish()
-        };
-        if !query_string.is_empty() {
-            uri += "?";
-            uri += &query_string;
-        }
-
-        let uri = match Uri::from_str(&uri) {
-            Ok(uri) => uri,
-            Err(err) => return Err(ApiError(format!("Unable to build URI: {}", err))),
-        };
-
-        let mut request = match Request::builder()
-            .method("PUT")
-            .uri(uri)
-            .body(Body::empty()) {
-                Ok(req) => req,
-                Err(e) => return Err(ApiError(format!("Unable to create request: {}", e)))
-        };
-
-        let body = serde_json::to_string(&param_user).expect("impossible to fail to serialize");
-
-                *request.body_mut() = Body::from(body);
-
-        let header = "application/json";
-        request.headers_mut().insert(CONTENT_TYPE, match HeaderValue::from_str(header) {
-            Ok(h) => h,
-            Err(e) => return Err(ApiError(format!("Unable to create header: {} - {}", header, e)))
-        });
-
-        let header = HeaderValue::from_str(Has::<XSpanIdString>::get(context).0.clone().to_string().as_str());
-        request.headers_mut().insert(HeaderName::from_static("x-span-id"), match header {
-            Ok(h) => h,
-            Err(e) => return Err(ApiError(format!("Unable to create X-Span ID header value: {}", e)))
-        });
-
-        if let Some(auth_data) = Has::<Option<AuthData>>::get(context).as_ref() {
-            // Currently only authentication with Basic and Bearer are supported
-            match auth_data {
-                &AuthData::Bearer(ref bearer_header) => {
-                    let auth = swagger::auth::Header(bearer_header.clone());
-                    let header = match HeaderValue::from_str(&format!("{}", auth)) {
-                        Ok(h) => h,
-                        Err(e) => return Err(ApiError(format!("Unable to create Authorization header: {}", e)))
-                    };
-                    request.headers_mut().insert(
-                        hyper::header::AUTHORIZATION,
-                        header);
-                },
-                _ => {}
-            }
-        }
-
-        let mut response = client_service.call((request, context.clone()))
-            .map_err(|e| ApiError(format!("No response received: {}", e))).await?;
-
-        match response.status().as_u16() {
-            200 => {
-                let body = response.into_body();
-                let body = body
-                        .to_raw()
-                        .map_err(|e| ApiError(format!("Failed to read response: {}", e))).await?;
-                let body = str::from_utf8(&body)
-                    .map_err(|e| ApiError(format!("Response was not valid UTF8: {}", e)))?;
-                let body = serde_json::from_str::<models::User>(body)?;
-                Ok(UpdateUserInfoResponse::SuccessfulOperation
-                    (body)
-                )
-            }
-            405 => {
-                let body = response.into_body();
-                Ok(
-                    UpdateUserInfoResponse::InvalidInput
-                )
-            }
-            code => {
-                let headers = response.headers().clone();
-                let body = response.into_body()
-                       .take(100)
-                       .to_raw().await;
-                Err(ApiError(format!("Unexpected response code {}:\n{:?}\n\n{}",
-                    code,
-                    headers,
-                    match body {
-                        Ok(body) => match String::from_utf8(body) {
-                            Ok(body) => body,
-                            Err(e) => format!("<Body was not UTF8: {:?}>", e),
-                        },
-                        Err(e) => format!("<Failed to read body: {}>", e),
-                    }
-                )))
-            }
-        }
-    }
-
     async fn query_user_by_id(
         &self,
         param_id: uuid::Uuid,
@@ -711,7 +696,7 @@ impl<S, C> Api<C> for Client<S, C> where
     {
         let mut client_service = self.client_service.clone();
         let mut uri = format!(
-            "{}/query-api/user/{id}",
+            "{}/query-api/users/{id}",
             self.base_path
             ,id=utf8_percent_encode(&param_id.to_string(), ID_ENCODE_SET)
         );
@@ -819,7 +804,7 @@ impl<S, C> Api<C> for Client<S, C> where
     {
         let mut client_service = self.client_service.clone();
         let mut uri = format!(
-            "{}/query-api/users/",
+            "{}/query-api/users",
             self.base_path
         );
 
