@@ -22,9 +22,9 @@ pub use crate::context;
 type ServiceFuture = BoxFuture<'static, Result<Response<Body>, crate::ServiceError>>;
 
 use crate::{Api,
-     DeactiveUserResponse,
+     ActivateUserResponse,
+     DeactivateUserResponse,
      UpdatePasswordResponse,
-     UpdateUserInfoResponse,
      QueryUserByIdResponse,
      QueryUsersResponse
 };
@@ -34,39 +34,24 @@ mod paths {
 
     lazy_static! {
         pub static ref GLOBAL_REGEX_SET: regex::RegexSet = regex::RegexSet::new(vec![
-            r"^/mutation-api/user/deactive/(?P<id>[^/?#]*)$",
-            r"^/mutation-api/user/update-info/(?P<id>[^/?#]*)$",
-            r"^/mutation-api/user/update-password/(?P<id>[^/?#]*)$",
-            r"^/query-api/user/(?P<id>[^/?#]*)$",
-            r"^/query-api/users/$"
+            r"^/mutation-api/users/activation$",
+            r"^/mutation-api/users/deactivation$",
+            r"^/mutation-api/users/password$",
+            r"^/query-api/users$",
+            r"^/query-api/users/(?P<id>[^/?#]*)$"
         ])
         .expect("Unable to create global regex set");
     }
-    pub(crate) static ID_MUTATION_API_USER_DEACTIVE_ID: usize = 0;
+    pub(crate) static ID_MUTATION_API_USERS_ACTIVATION: usize = 0;
+    pub(crate) static ID_MUTATION_API_USERS_DEACTIVATION: usize = 1;
+    pub(crate) static ID_MUTATION_API_USERS_PASSWORD: usize = 2;
+    pub(crate) static ID_QUERY_API_USERS: usize = 3;
+    pub(crate) static ID_QUERY_API_USERS_ID: usize = 4;
     lazy_static! {
-        pub static ref REGEX_MUTATION_API_USER_DEACTIVE_ID: regex::Regex =
-            regex::Regex::new(r"^/mutation-api/user/deactive/(?P<id>[^/?#]*)$")
-                .expect("Unable to create regex for MUTATION_API_USER_DEACTIVE_ID");
+        pub static ref REGEX_QUERY_API_USERS_ID: regex::Regex =
+            regex::Regex::new(r"^/query-api/users/(?P<id>[^/?#]*)$")
+                .expect("Unable to create regex for QUERY_API_USERS_ID");
     }
-    pub(crate) static ID_MUTATION_API_USER_UPDATE_INFO_ID: usize = 1;
-    lazy_static! {
-        pub static ref REGEX_MUTATION_API_USER_UPDATE_INFO_ID: regex::Regex =
-            regex::Regex::new(r"^/mutation-api/user/update-info/(?P<id>[^/?#]*)$")
-                .expect("Unable to create regex for MUTATION_API_USER_UPDATE_INFO_ID");
-    }
-    pub(crate) static ID_MUTATION_API_USER_UPDATE_PASSWORD_ID: usize = 2;
-    lazy_static! {
-        pub static ref REGEX_MUTATION_API_USER_UPDATE_PASSWORD_ID: regex::Regex =
-            regex::Regex::new(r"^/mutation-api/user/update-password/(?P<id>[^/?#]*)$")
-                .expect("Unable to create regex for MUTATION_API_USER_UPDATE_PASSWORD_ID");
-    }
-    pub(crate) static ID_QUERY_API_USER_ID: usize = 3;
-    lazy_static! {
-        pub static ref REGEX_QUERY_API_USER_ID: regex::Regex =
-            regex::Regex::new(r"^/query-api/user/(?P<id>[^/?#]*)$")
-                .expect("Unable to create regex for QUERY_API_USER_ID");
-    }
-    pub(crate) static ID_QUERY_API_USERS_: usize = 4;
 }
 
 pub struct MakeService<T, C> where
@@ -171,8 +156,8 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
 
         match &method {
 
-            // DeactiveUser - PUT /mutation-api/user/deactive/{id}
-            &hyper::Method::PUT if path.matched(paths::ID_MUTATION_API_USER_DEACTIVE_ID) => {
+            // ActivateUser - POST /mutation-api/users/activation
+            &hyper::Method::POST if path.matched(paths::ID_MUTATION_API_USERS_ACTIVATION) => {
                 {
                     let authorization = match (&context as &dyn Has<Option<Authorization>>).get() {
                         &Some(ref authorization) => authorization,
@@ -183,31 +168,7 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                     };
                 }
 
-                // Path parameters
-                let path: &str = &uri.path().to_string();
-                let path_params =
-                    paths::REGEX_MUTATION_API_USER_DEACTIVE_ID
-                    .captures(&path)
-                    .unwrap_or_else(||
-                        panic!("Path {} matched RE MUTATION_API_USER_DEACTIVE_ID in set but failed match against \"{}\"", path, paths::REGEX_MUTATION_API_USER_DEACTIVE_ID.as_str())
-                    );
-
-                let param_id = match percent_encoding::percent_decode(path_params["id"].as_bytes()).decode_utf8() {
-                    Ok(param_id) => match param_id.parse::<uuid::Uuid>() {
-                        Ok(param_id) => param_id,
-                        Err(e) => return Ok(Response::builder()
-                                        .status(StatusCode::BAD_REQUEST)
-                                        .body(Body::from(format!("Couldn't parse path parameter id: {}", e)))
-                                        .expect("Unable to create Bad Request response for invalid path parameter")),
-                    },
-                    Err(_) => return Ok(Response::builder()
-                                        .status(StatusCode::BAD_REQUEST)
-                                        .body(Body::from(format!("Couldn't percent-decode path parameter as UTF-8: {}", &path_params["id"])))
-                                        .expect("Unable to create Bad Request response for invalid percent decode"))
-                };
-
-                                let result = api_impl.deactive_user(
-                                            param_id,
+                                let result = api_impl.activate_user(
                                         &context
                                     ).await;
                                 let mut response = Response::new(Body::empty());
@@ -218,18 +179,18 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
 
                                         match result {
                                             Ok(rsp) => match rsp {
-                                                DeactiveUserResponse::SuccessfulOperation
+                                                ActivateUserResponse::SuccessfulOperation
                                                     (body)
                                                 => {
                                                     *response.status_mut() = StatusCode::from_u16(200).expect("Unable to turn 200 into a StatusCode");
                                                     response.headers_mut().insert(
                                                         CONTENT_TYPE,
                                                         HeaderValue::from_str("application/json")
-                                                            .expect("Unable to create Content-Type header for DEACTIVE_USER_SUCCESSFUL_OPERATION"));
+                                                            .expect("Unable to create Content-Type header for ACTIVATE_USER_SUCCESSFUL_OPERATION"));
                                                     let body = serde_json::to_string(&body).expect("impossible to fail to serialize");
                                                     *response.body_mut() = Body::from(body);
                                                 },
-                                                DeactiveUserResponse::InvalidInput
+                                                ActivateUserResponse::InvalidInput
                                                 => {
                                                     *response.status_mut() = StatusCode::from_u16(405).expect("Unable to turn 405 into a StatusCode");
                                                 },
@@ -245,8 +206,8 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                                         Ok(response)
             },
 
-            // UpdatePassword - PUT /mutation-api/user/update-password/{id}
-            &hyper::Method::PUT if path.matched(paths::ID_MUTATION_API_USER_UPDATE_PASSWORD_ID) => {
+            // DeactivateUser - POST /mutation-api/users/deactivation
+            &hyper::Method::POST if path.matched(paths::ID_MUTATION_API_USERS_DEACTIVATION) => {
                 {
                     let authorization = match (&context as &dyn Has<Option<Authorization>>).get() {
                         &Some(ref authorization) => authorization,
@@ -257,28 +218,55 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                     };
                 }
 
-                // Path parameters
-                let path: &str = &uri.path().to_string();
-                let path_params =
-                    paths::REGEX_MUTATION_API_USER_UPDATE_PASSWORD_ID
-                    .captures(&path)
-                    .unwrap_or_else(||
-                        panic!("Path {} matched RE MUTATION_API_USER_UPDATE_PASSWORD_ID in set but failed match against \"{}\"", path, paths::REGEX_MUTATION_API_USER_UPDATE_PASSWORD_ID.as_str())
-                    );
+                                let result = api_impl.deactivate_user(
+                                        &context
+                                    ).await;
+                                let mut response = Response::new(Body::empty());
+                                response.headers_mut().insert(
+                                            HeaderName::from_static("x-span-id"),
+                                            HeaderValue::from_str((&context as &dyn Has<XSpanIdString>).get().0.clone().to_string().as_str())
+                                                .expect("Unable to create X-Span-ID header value"));
 
-                let param_id = match percent_encoding::percent_decode(path_params["id"].as_bytes()).decode_utf8() {
-                    Ok(param_id) => match param_id.parse::<uuid::Uuid>() {
-                        Ok(param_id) => param_id,
-                        Err(e) => return Ok(Response::builder()
-                                        .status(StatusCode::BAD_REQUEST)
-                                        .body(Body::from(format!("Couldn't parse path parameter id: {}", e)))
-                                        .expect("Unable to create Bad Request response for invalid path parameter")),
-                    },
-                    Err(_) => return Ok(Response::builder()
-                                        .status(StatusCode::BAD_REQUEST)
-                                        .body(Body::from(format!("Couldn't percent-decode path parameter as UTF-8: {}", &path_params["id"])))
-                                        .expect("Unable to create Bad Request response for invalid percent decode"))
-                };
+                                        match result {
+                                            Ok(rsp) => match rsp {
+                                                DeactivateUserResponse::SuccessfulOperation
+                                                    (body)
+                                                => {
+                                                    *response.status_mut() = StatusCode::from_u16(200).expect("Unable to turn 200 into a StatusCode");
+                                                    response.headers_mut().insert(
+                                                        CONTENT_TYPE,
+                                                        HeaderValue::from_str("application/json")
+                                                            .expect("Unable to create Content-Type header for DEACTIVATE_USER_SUCCESSFUL_OPERATION"));
+                                                    let body = serde_json::to_string(&body).expect("impossible to fail to serialize");
+                                                    *response.body_mut() = Body::from(body);
+                                                },
+                                                DeactivateUserResponse::InvalidInput
+                                                => {
+                                                    *response.status_mut() = StatusCode::from_u16(405).expect("Unable to turn 405 into a StatusCode");
+                                                },
+                                            },
+                                            Err(_) => {
+                                                // Application code returned an error. This should not happen, as the implementation should
+                                                // return a valid response.
+                                                *response.status_mut() = StatusCode::INTERNAL_SERVER_ERROR;
+                                                *response.body_mut() = Body::from("An internal error occurred");
+                                            },
+                                        }
+
+                                        Ok(response)
+            },
+
+            // UpdatePassword - PUT /mutation-api/users/password
+            &hyper::Method::PUT if path.matched(paths::ID_MUTATION_API_USERS_PASSWORD) => {
+                {
+                    let authorization = match (&context as &dyn Has<Option<Authorization>>).get() {
+                        &Some(ref authorization) => authorization,
+                        &None => return Ok(Response::builder()
+                                                .status(StatusCode::FORBIDDEN)
+                                                .body(Body::from("Unauthenticated"))
+                                                .expect("Unable to create Authentication Forbidden response")),
+                    };
+                }
 
                 // Body parameters (note that non-required body parameters will ignore garbage
                 // values, rather than causing a 400 response). Produce warning header and logs for
@@ -311,7 +299,6 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                                 };
 
                                 let result = api_impl.update_password(
-                                            param_id,
                                             param_inline_object,
                                         &context
                                     ).await;
@@ -363,8 +350,8 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                         }
             },
 
-            // UpdateUserInfo - PUT /mutation-api/user/update-info/{id}
-            &hyper::Method::PUT if path.matched(paths::ID_MUTATION_API_USER_UPDATE_INFO_ID) => {
+            // QueryUserById - GET /query-api/users/{id}
+            &hyper::Method::GET if path.matched(paths::ID_QUERY_API_USERS_ID) => {
                 {
                     let authorization = match (&context as &dyn Has<Option<Authorization>>).get() {
                         &Some(ref authorization) => authorization,
@@ -378,128 +365,10 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                 // Path parameters
                 let path: &str = &uri.path().to_string();
                 let path_params =
-                    paths::REGEX_MUTATION_API_USER_UPDATE_INFO_ID
+                    paths::REGEX_QUERY_API_USERS_ID
                     .captures(&path)
                     .unwrap_or_else(||
-                        panic!("Path {} matched RE MUTATION_API_USER_UPDATE_INFO_ID in set but failed match against \"{}\"", path, paths::REGEX_MUTATION_API_USER_UPDATE_INFO_ID.as_str())
-                    );
-
-                let param_id = match percent_encoding::percent_decode(path_params["id"].as_bytes()).decode_utf8() {
-                    Ok(param_id) => match param_id.parse::<uuid::Uuid>() {
-                        Ok(param_id) => param_id,
-                        Err(e) => return Ok(Response::builder()
-                                        .status(StatusCode::BAD_REQUEST)
-                                        .body(Body::from(format!("Couldn't parse path parameter id: {}", e)))
-                                        .expect("Unable to create Bad Request response for invalid path parameter")),
-                    },
-                    Err(_) => return Ok(Response::builder()
-                                        .status(StatusCode::BAD_REQUEST)
-                                        .body(Body::from(format!("Couldn't percent-decode path parameter as UTF-8: {}", &path_params["id"])))
-                                        .expect("Unable to create Bad Request response for invalid percent decode"))
-                };
-
-                // Body parameters (note that non-required body parameters will ignore garbage
-                // values, rather than causing a 400 response). Produce warning header and logs for
-                // any unused fields.
-                let result = body.to_raw().await;
-                match result {
-                            Ok(body) => {
-                                let mut unused_elements = Vec::new();
-                                let param_user: Option<models::User> = if !body.is_empty() {
-                                    let deserializer = &mut serde_json::Deserializer::from_slice(&*body);
-                                    match serde_ignored::deserialize(deserializer, |path| {
-                                            warn!("Ignoring unknown field in body: {}", path);
-                                            unused_elements.push(path.to_string());
-                                    }) {
-                                        Ok(param_user) => param_user,
-                                        Err(e) => return Ok(Response::builder()
-                                                        .status(StatusCode::BAD_REQUEST)
-                                                        .body(Body::from(format!("Couldn't parse body parameter User - doesn't match schema: {}", e)))
-                                                        .expect("Unable to create Bad Request response for invalid body parameter User due to schema")),
-                                    }
-                                } else {
-                                    None
-                                };
-                                let param_user = match param_user {
-                                    Some(param_user) => param_user,
-                                    None => return Ok(Response::builder()
-                                                        .status(StatusCode::BAD_REQUEST)
-                                                        .body(Body::from("Missing required body parameter User"))
-                                                        .expect("Unable to create Bad Request response for missing body parameter User")),
-                                };
-
-                                let result = api_impl.update_user_info(
-                                            param_id,
-                                            param_user,
-                                        &context
-                                    ).await;
-                                let mut response = Response::new(Body::empty());
-                                response.headers_mut().insert(
-                                            HeaderName::from_static("x-span-id"),
-                                            HeaderValue::from_str((&context as &dyn Has<XSpanIdString>).get().0.clone().to_string().as_str())
-                                                .expect("Unable to create X-Span-ID header value"));
-
-                                        if !unused_elements.is_empty() {
-                                            response.headers_mut().insert(
-                                                HeaderName::from_static("warning"),
-                                                HeaderValue::from_str(format!("Ignoring unknown fields in body: {:?}", unused_elements).as_str())
-                                                    .expect("Unable to create Warning header value"));
-                                        }
-
-                                        match result {
-                                            Ok(rsp) => match rsp {
-                                                UpdateUserInfoResponse::SuccessfulOperation
-                                                    (body)
-                                                => {
-                                                    *response.status_mut() = StatusCode::from_u16(200).expect("Unable to turn 200 into a StatusCode");
-                                                    response.headers_mut().insert(
-                                                        CONTENT_TYPE,
-                                                        HeaderValue::from_str("application/json")
-                                                            .expect("Unable to create Content-Type header for UPDATE_USER_INFO_SUCCESSFUL_OPERATION"));
-                                                    let body = serde_json::to_string(&body).expect("impossible to fail to serialize");
-                                                    *response.body_mut() = Body::from(body);
-                                                },
-                                                UpdateUserInfoResponse::InvalidInput
-                                                => {
-                                                    *response.status_mut() = StatusCode::from_u16(405).expect("Unable to turn 405 into a StatusCode");
-                                                },
-                                            },
-                                            Err(_) => {
-                                                // Application code returned an error. This should not happen, as the implementation should
-                                                // return a valid response.
-                                                *response.status_mut() = StatusCode::INTERNAL_SERVER_ERROR;
-                                                *response.body_mut() = Body::from("An internal error occurred");
-                                            },
-                                        }
-
-                                        Ok(response)
-                            },
-                            Err(e) => Ok(Response::builder()
-                                                .status(StatusCode::BAD_REQUEST)
-                                                .body(Body::from(format!("Couldn't read body parameter User: {}", e)))
-                                                .expect("Unable to create Bad Request response due to unable to read body parameter User")),
-                        }
-            },
-
-            // QueryUserById - GET /query-api/user/{id}
-            &hyper::Method::GET if path.matched(paths::ID_QUERY_API_USER_ID) => {
-                {
-                    let authorization = match (&context as &dyn Has<Option<Authorization>>).get() {
-                        &Some(ref authorization) => authorization,
-                        &None => return Ok(Response::builder()
-                                                .status(StatusCode::FORBIDDEN)
-                                                .body(Body::from("Unauthenticated"))
-                                                .expect("Unable to create Authentication Forbidden response")),
-                    };
-                }
-
-                // Path parameters
-                let path: &str = &uri.path().to_string();
-                let path_params =
-                    paths::REGEX_QUERY_API_USER_ID
-                    .captures(&path)
-                    .unwrap_or_else(||
-                        panic!("Path {} matched RE QUERY_API_USER_ID in set but failed match against \"{}\"", path, paths::REGEX_QUERY_API_USER_ID.as_str())
+                        panic!("Path {} matched RE QUERY_API_USERS_ID in set but failed match against \"{}\"", path, paths::REGEX_QUERY_API_USERS_ID.as_str())
                     );
 
                 let param_id = match percent_encoding::percent_decode(path_params["id"].as_bytes()).decode_utf8() {
@@ -559,8 +428,8 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                                         Ok(response)
             },
 
-            // QueryUsers - GET /query-api/users/
-            &hyper::Method::GET if path.matched(paths::ID_QUERY_API_USERS_) => {
+            // QueryUsers - GET /query-api/users
+            &hyper::Method::GET if path.matched(paths::ID_QUERY_API_USERS) => {
                 {
                     let authorization = match (&context as &dyn Has<Option<Authorization>>).get() {
                         &Some(ref authorization) => authorization,
@@ -670,11 +539,11 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                                         Ok(response)
             },
 
-            _ if path.matched(paths::ID_MUTATION_API_USER_DEACTIVE_ID) => method_not_allowed(),
-            _ if path.matched(paths::ID_MUTATION_API_USER_UPDATE_INFO_ID) => method_not_allowed(),
-            _ if path.matched(paths::ID_MUTATION_API_USER_UPDATE_PASSWORD_ID) => method_not_allowed(),
-            _ if path.matched(paths::ID_QUERY_API_USER_ID) => method_not_allowed(),
-            _ if path.matched(paths::ID_QUERY_API_USERS_) => method_not_allowed(),
+            _ if path.matched(paths::ID_MUTATION_API_USERS_ACTIVATION) => method_not_allowed(),
+            _ if path.matched(paths::ID_MUTATION_API_USERS_DEACTIVATION) => method_not_allowed(),
+            _ if path.matched(paths::ID_MUTATION_API_USERS_PASSWORD) => method_not_allowed(),
+            _ if path.matched(paths::ID_QUERY_API_USERS) => method_not_allowed(),
+            _ if path.matched(paths::ID_QUERY_API_USERS_ID) => method_not_allowed(),
             _ => Ok(Response::builder().status(StatusCode::NOT_FOUND)
                     .body(Body::empty())
                     .expect("Unable to create Not Found response"))
@@ -688,16 +557,16 @@ impl<T> RequestParser<T> for ApiRequestParser {
     fn parse_operation_id(request: &Request<T>) -> Result<&'static str, ()> {
         let path = paths::GLOBAL_REGEX_SET.matches(request.uri().path());
         match request.method() {
-            // DeactiveUser - PUT /mutation-api/user/deactive/{id}
-            &hyper::Method::PUT if path.matched(paths::ID_MUTATION_API_USER_DEACTIVE_ID) => Ok("DeactiveUser"),
-            // UpdatePassword - PUT /mutation-api/user/update-password/{id}
-            &hyper::Method::PUT if path.matched(paths::ID_MUTATION_API_USER_UPDATE_PASSWORD_ID) => Ok("UpdatePassword"),
-            // UpdateUserInfo - PUT /mutation-api/user/update-info/{id}
-            &hyper::Method::PUT if path.matched(paths::ID_MUTATION_API_USER_UPDATE_INFO_ID) => Ok("UpdateUserInfo"),
-            // QueryUserById - GET /query-api/user/{id}
-            &hyper::Method::GET if path.matched(paths::ID_QUERY_API_USER_ID) => Ok("QueryUserById"),
-            // QueryUsers - GET /query-api/users/
-            &hyper::Method::GET if path.matched(paths::ID_QUERY_API_USERS_) => Ok("QueryUsers"),
+            // ActivateUser - POST /mutation-api/users/activation
+            &hyper::Method::POST if path.matched(paths::ID_MUTATION_API_USERS_ACTIVATION) => Ok("ActivateUser"),
+            // DeactivateUser - POST /mutation-api/users/deactivation
+            &hyper::Method::POST if path.matched(paths::ID_MUTATION_API_USERS_DEACTIVATION) => Ok("DeactivateUser"),
+            // UpdatePassword - PUT /mutation-api/users/password
+            &hyper::Method::PUT if path.matched(paths::ID_MUTATION_API_USERS_PASSWORD) => Ok("UpdatePassword"),
+            // QueryUserById - GET /query-api/users/{id}
+            &hyper::Method::GET if path.matched(paths::ID_QUERY_API_USERS_ID) => Ok("QueryUserById"),
+            // QueryUsers - GET /query-api/users
+            &hyper::Method::GET if path.matched(paths::ID_QUERY_API_USERS) => Ok("QueryUsers"),
             _ => Err(()),
         }
     }
